@@ -1,10 +1,8 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import datetime
 import json
 
 import flask
+from werkzeug.wrappers import Response
 
 from git_code_debt.server import logic
 from git_code_debt.server.render_mako import render_template
@@ -16,9 +14,9 @@ graph = flask.Blueprint('graph', __name__)
 
 
 @graph.route('/graph/<metric_name>')
-def show(metric_name):
-    start_timestamp = int(flask.request.args.get('start'))
-    end_timestamp = int(flask.request.args.get('end'))
+def show(metric_name: str) -> str:
+    start_timestamp = int(flask.request.args['start'])
+    end_timestamp = int(flask.request.args['end'])
 
     metric_info = logic.get_metric_info(flask.g.db, metric_name)
 
@@ -38,25 +36,27 @@ def show(metric_name):
         description=metric_info.description,
         metric_name=metric_name,
         metrics=json.dumps(metrics_for_js),
-        start_timestamp=start_timestamp,
-        end_timestamp=end_timestamp,
+        start_ts=start_timestamp,
+        end_ts=end_timestamp,
         changes_url=flask.url_for(
             'changes.show',
             metric_name=metric_name,
-            start_timestamp=start_timestamp,
-            end_timestamp=end_timestamp,
+            start_ts=start_timestamp,
+            end_ts=end_timestamp,
         ),
     )
 
 
 @graph.route('/graph/<metric_name>/all_data')
-def all_data(metric_name):
+def all_data(metric_name: str) -> Response:
     earliest_timestamp = logic.get_first_data_timestamp(metric_name)
     now = datetime.datetime.today()
 
-    return flask.redirect(flask.url_for(
-        'graph.show',
-        metric_name=metric_name,
-        start=str(earliest_timestamp),
-        end=str(to_timestamp(now)),
-    ))
+    return flask.redirect(
+        flask.url_for(
+            'graph.show',
+            metric_name=metric_name,
+            start=str(earliest_timestamp),
+            end=str(to_timestamp(now)),
+        ),
+    )
